==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/plugins/page-structure/components/PageStructureSidebarSection.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/plugins/page-structure/components/PageStructureSidebarSection", ['module', 'exports', 'require', 'frontend-js-react-web$classnames', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = PageStructureSidebarSection;

    var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var MIN_HEIGHT = 100;

    function PageStructureSidebarSection(_ref) {
      var children = _ref.children,
          _ref$resizable = _ref.resizable,
          resizable = _ref$resizable === void 0 ? false : _ref$resizable,
          _ref$size = _ref.size,
          size = _ref$size === void 0 ? 1 : _ref$size;

      var _useState = (0, _react.useState)(null),
          _useState2 = _slicedToArray(_useState, 2),
          handlerElement = _useState2[0],
          setHandlerElement = _useState2[1];

      var _useState3 = (0, _react.useState)(null),
          _useState4 = _slicedToArray(_useState3, 2),
          panelElement = _useState4[0],
          setPanelElement = _useState4[1];

      var _useState5 = (0, _react.useState)(),
          _useState6 = _slicedToArray(_useState5, 2),
          panelHeight = _useState6[0],
          setPanelHeight = _useState6[1];

      var _useState7 = (0, _react.useState)(false),
          _useState8 = _slicedToArray(_useState7, 2),
          resizing = _useState8[0],
          setResizing = _useState8[1];

      (0, _react.useEffect)(function () {
        if (!handlerElement || !panelElement) {
          return;
        }

        var initialHeight = 0;
        var initialY = 0;
        var maxHeight = 0;

        var handleResizeStart = function handleResizeStart(event) {
          var _panelElement$previou, _panelElement$previou2;

          initialHeight = panelElement.getBoundingClientRect().height;
          initialY = event.clientY;
          maxHeight = initialHeight + ((handlerElement === null || handlerElement === void 0 ? void 0 : handlerElement.getBoundingClientRect().height) || 0) + (((_panelElement$previou = panelElement.previousSibling) === null || _panelElement$previou === void 0 ? void 0 : (_panelElement$previou2 = _panelElement$previou.previousSibling) === null || _panelElement$previou2 === void 0 ? void 0 : _panelElement$previou2.getBoundingClientRect().height) || 0) - MIN_HEIGHT;
          document.body.addEventListener('mousemove', handleResize);
          document.body.addEventListener('mouseleave', handleResizeEnd);
          document.body.addEventListener('mouseup', handleResizeEnd);
          setResizing(true);
        };

        var handleResize = function handleResize(event) {
          var delta = event.clientY - initialY;
          setPanelHeight(Math.max(Math.min(maxHeight, initialHeight - delta), MIN_HEIGHT));
        };

        var handleResizeEnd = function handleResizeEnd() {
          document.body.removeEventListener('mousemove', handleResize);
          document.body.removeEventListener('mouseleave', handleResizeEnd);
          document.body.removeEventListener('mouseup', handleResizeEnd);
          setResizing(false);
        };

        handlerElement.addEventListener('mousedown', handleResizeStart);
        return function () {
          handlerElement.removeEventListener('mousedown', handleResizeStart);
          handleResizeEnd();
        };
      }, [handlerElement, panelElement]);
      return _react["default"].createElement(_react["default"].Fragment, null, resizable && _react["default"].createElement("div", {
        className: (0, _classnames["default"])('page-editor__page-structure__section__resize-handler', {
          active: resizing
        }),
        ref: setHandlerElement
      }), _react["default"].createElement("div", {
        className: (0, _classnames["default"])('page-editor__page-structure__section', {
          resized: !!panelHeight
        }),
        ref: setPanelElement,
        style: {
          flexGrow: panelHeight ? 0 : size,
          height: panelHeight
        }
      }, children));
    }
    //# sourceMappingURL=PageStructureSidebarSection.js.map
  }
});
//# sourceMappingURL=PageStructureSidebarSection.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/plugins/page-structure/components/PageStructureSidebarSection.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/plugins/page-structure/components/PageStructureSidebarSection", ['module', 'exports', 'require', 'frontend-js-react-web$classnames', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = PageStructureSidebarSection;

    var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var MIN_HEIGHT = 100;

    function PageStructureSidebarSection(_ref) {
      var children = _ref.children,
          _ref$resizable = _ref.resizable,
          resizable = _ref$resizable === void 0 ? false : _ref$resizable,
          _ref$size = _ref.size,
          size = _ref$size === void 0 ? 1 : _ref$size;

      var _useState = (0, _react.useState)(null),
          _useState2 = _slicedToArray(_useState, 2),
          handlerElement = _useState2[0],
          setHandlerElement = _useState2[1];

      var _useState3 = (0, _react.useState)(null),
          _useState4 = _slicedToArray(_useState3, 2),
          panelElement = _useState4[0],
          setPanelElement = _useState4[1];

      var _useState5 = (0, _react.useState)(),
          _useState6 = _slicedToArray(_useState5, 2),
          panelHeight = _useState6[0],
          setPanelHeight = _useState6[1];

      var _useState7 = (0, _react.useState)(false),
          _useState8 = _slicedToArray(_useState7, 2),
          resizing = _useState8[0],
          setResizing = _useState8[1];

      (0, _react.useEffect)(function () {
        if (!handlerElement || !panelElement) {
          return;
        }

        var initialHeight = 0;
        var initialY = 0;
        var maxHeight = 0;

        var handleResize = function handleResize(event) {
          var delta = event.clientY - initialY;
          setPanelHeight(Math.max(Math.min(maxHeight, initialHeight - delta), MIN_HEIGHT));
        };

        var handleResizeEnd = function handleResizeEnd() {
          document.body.removeEventListener('mousemove', handleResize);
          document.body.removeEventListener('mouseleave', handleResizeEnd);
          document.body.removeEventListener('mouseup', handleResizeEnd);
          setResizing(false);
        };

        var handleResizeStart = function handleResizeStart(event) {
          var _panelElement$previou, _panelElement$previou2;

          initialHeight = panelElement.getBoundingClientRect().height;
          initialY = event.clientY;
          maxHeight = initialHeight + ((handlerElement === null || handlerElement === void 0 ? void 0 : handlerElement.getBoundingClientRect().height) || 0) + (((_panelElement$previou = panelElement.previousSibling) === null || _panelElement$previou === void 0 ? void 0 : (_panelElement$previou2 = _panelElement$previou.previousSibling) === null || _panelElement$previou2 === void 0 ? void 0 : _panelElement$previou2.getBoundingClientRect().height) || 0) - MIN_HEIGHT;
          document.body.addEventListener('mousemove', handleResize);
          document.body.addEventListener('mouseleave', handleResizeEnd);
          document.body.addEventListener('mouseup', handleResizeEnd);
          setResizing(true);
        };

        handlerElement.addEventListener('mousedown', handleResizeStart);
        return function () {
          handlerElement.removeEventListener('mousedown', handleResizeStart);
          handleResizeEnd();
        };
      }, [handlerElement, panelElement]);
      return (/*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, resizable && /*#__PURE__*/_react.default.createElement("div", {
          className: (0, _classnames.default)('page-editor__page-structure__section__resize-handler', {
            active: resizing
          }),
          ref: setHandlerElement
        }), /*#__PURE__*/_react.default.createElement("div", {
          className: (0, _classnames.default)('page-editor__page-structure__section', {
            resized: !!panelHeight
          }),
          ref: setPanelElement,
          style: {
            flexGrow: panelHeight ? 0 : size,
            height: panelHeight
          }
        }, children))
      );
    }
    //# sourceMappingURL=PageStructureSidebarSection.js.map
  }
});
//# sourceMappingURL=PageStructureSidebarSection.js.map
